@@ -8,7 +8,7 @@ use File::Spec;
 use File::Path qw( mkpath );
 
 # ABSTRACT: Parallel SSH client server side code
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 
 # This is the implementation of the clad server.
@@ -114,6 +114,8 @@ sub _server
   #         is_dir
   #         content
   #         mode
+  #
+  #   stdin: optional scalar            [ 1.04 ]
 
   if(ref $payload->{command} ne 'ARRAY' || @{ $payload->{command} } == 0)
   {
@@ -187,6 +189,15 @@ sub _server
 
   $ENV{$_} = $payload->{env}->{$_} for keys %{ $payload->{env} };
   
+  if(defined $payload->{stdin})
+  {
+    my $filename = File::Spec->catfile(tempdir(CLEANUP => 1), 'stdin.txt');
+    open OUT, ">$filename"; 
+    print OUT $payload->{stdin};
+    close OUT;
+    open STDIN, "<$filename";
+  }
+  
   system @{ $payload->{command} };
   
   if($? == -1)
@@ -217,7 +228,7 @@ Clustericious::Admin::Server - Parallel SSH client server side code
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
